@@ -1,6 +1,6 @@
 #!/bin/sh
 # Run this to generate all the initial makefiles, etc.
-# $Id: autogen.sh,v 1.1.1.1.2.1 1999/08/19 00:40:54 mej Exp $
+# $Id: autogen.sh,v 1.5 2002/01/30 16:59:08 gilbertt Exp $
 
 DIE=0
 
@@ -34,26 +34,22 @@ if test "$DIE" -eq 1; then
         exit 1
 fi
 
-echo "  libtoolize --copy --force"
-libtoolize --copy --force
+echo "  libtoolize -c -f"
+libtoolize -c -f
 echo "  aclocal -I . $ACLOCAL_FLAGS"
 aclocal -I . $ACLOCAL_FLAGS
-echo "  autoheader"
-autoheader
-echo "  automake --add-missing"
-automake --add-missing
 echo "  autoconf"
 autoconf
+echo "  autoheader"
+autoheader
+echo "  automake -a -c"
+automake -a -c
 
-if [ -x config.status -a -z "$*" ]; then
-  ./config.status --recheck
-else
-  if test -z "$*"; then
-    echo "I am going to run ./configure with no arguments - if you wish "
-    echo "to pass any to it, please specify them on the $0 command line."
-    echo "If you do not wish to run ./configure, press Ctrl-C now."
-    trap 'echo "configure aborted" ; exit 0' 1 2 15
-    sleep 1
-  fi
-  ./configure "$@"
+./configure "$@"
+
+if [ -f cvs.motd ]; then
+  echo "ATTENTION CVS Users!"
+  echo ""
+  cat cvs.motd
+  echo ""
 fi
